Attribute VB_Name = "MMain"
'***********************************************************
'* Module:        MMain
'* Description:   Used in ChatHook example.
'* Author:        Craig Jasper, Jr.
'* Machine:       CRAIG [ID: CP_4850] | Windows 2000 Server (SP1)
'* Modified:      April 13, 2001
'* Notes:         Written in VB6 Enterprise Edition (Service Pack 5).
'*                Requires SpyWorks 6.2 Subclassing control
'*                (DWSBC36.OCX). Check out http://www.desaware.com
'*                Tested on America Online 5.0 Revision 205.103 only.
'***********************************************************

Option Explicit

Private Declare Function FindWindow Lib "user32" Alias "FindWindowA" _
    (ByVal lpClassName As String, _
    ByVal lpWindowName As String) As Long

Private Declare Function FindWindowEx Lib "user32" Alias "FindWindowExA" _
    (ByVal hWnd1 As Long, _
    ByVal hWnd2 As Long, _
    ByVal lpsz1 As String, _
    ByVal lpsz2 As String) As Long

Private Declare Function GetWindowText Lib "user32" Alias "GetWindowTextA" _
    (ByVal hWnd As Long, _
    ByVal lpString As String, _
    ByVal cch As Long) As Long

Private Declare Function IsWindow Lib "user32" _
    (ByVal hWnd As Long) As Long

Private Declare Function SetWindowPos Lib "user32" _
    (ByVal hWnd As Long, _
    ByVal hWndInsertAfter As Long, _
    ByVal X As Long, _
    ByVal Y As Long, _
    ByVal cx As Long, _
    ByVal cy As Long, _
    ByVal wFlags As Long) As Long

Private Declare Function ShowWindow Lib "user32" _
    (ByVal hWnd As Long, _
    ByVal nCmdShow As Long) As Long

Private Declare Sub Sleep Lib "kernel32" _
    (ByVal dwMilliseconds As Long)

Private Const HWND_NOTOPMOST = -2
Private Const HWND_TOPMOST = -1

Private Const INVALID_WINDOW = "The window is invalid."

Private Const SW_HIDE = 0

Private Const SWP_NOMOVE = 2
Private Const SWP_NOSIZE = 1
Private Const FLAGS = SWP_NOMOVE Or SWP_NOSIZE

'********************************************************************************
' Routine:        GetCaption
' Description:    Gets caption from window.
' Parameters:     hWnd (Long): Handle to get caption from.
' Returns:        String containing caption.
' Example:
'     MsgBox GetCaption(hWnd)
'********************************************************************************
Public Function GetCaption(hWnd As Long) As String
    On Error GoTo PROC_ERR
    
    Dim lngRet    As Long
    Dim strCap    As String * 256
    
    If IsWindow(hWnd) Then
        lngRet = GetWindowText(hWnd, strCap, 256)
        GetCaption = Left$(strCap, lngRet)
    Else
        MsgBox INVALID_WINDOW, vbCritical
    End If
    
    Exit Function
PROC_ERR:
    MsgBox Err.Description, vbCritical
End Function

'********************************************************************************
' Routine:        GetMDIClient
' Description:    Obtains handle to AOL's MDICLient.
' Returns:        Long value containing MDIClient's handle.
' Example:
'     MsgBox GetMDIClient
'********************************************************************************
Public Function GetMDIClient() As Long
    On Error GoTo PROC_ERR
    
    Dim lngAOLFrame As Long
    
    lngAOLFrame = FindWindow("AOL Frame25", vbNullString)
    GetMDIClient = FindWindowEx(lngAOLFrame, 0&, "MDIClient", vbNullString)
    
    Exit Function
PROC_ERR:
    MsgBox Err.Description, vbCritical
End Function

'********************************************************************************
' Routine:        HideWindow
' Description:    Hides window.
' Parameters:     hWnd (Long): Handle to window to hide.
' Example:
'     Call HideWindow(hWnd)
'********************************************************************************
Public Sub HideWindow(hWnd As Long)
    On Error GoTo PROC_ERR

    If IsWindow(hWnd) Then
        Call ShowWindow(hWnd, SW_HIDE)
    Else
        MsgBox INVALID_WINDOW, vbCritical
    End If

    Exit Sub
PROC_ERR:
    MsgBox Err.Description, vbCritical
End Sub

'********************************************************************************
' Routine:        IsChatRoom
' Description:    Determines if window is a chat room.
' Returns:        Boolean. True if chat room, False otherwise.
' Example:
'     MsgBox IsChatRoom
'********************************************************************************
Public Function IsChatRoom() As Boolean
    On Error GoTo PROC_ERR
    
    Dim lngAOLFrame     As Long
    Dim lngAOLChild     As Long
    Dim lngRICHCNTL     As Long
    Dim lngAOLList      As Long
    Dim lngAOLIcon      As Long
    Dim lngAOLStatic    As Long
    
    lngAOLFrame = FindWindow("AOL Frame25", vbNullString)
    lngAOLChild = FindWindowEx(GetMDIClient, 0&, "AOL Child", vbNullString)
    lngRICHCNTL = FindWindowEx(lngAOLChild, 0&, "RICHCNTL", vbNullString)
    lngRICHCNTL = FindWindowEx(lngAOLChild, lngRICHCNTL, "RICHCNTL", vbNullString)
    lngAOLIcon = FindWindowEx(lngAOLChild, 0&, "_AOL_Icon", vbNullString)
    lngAOLStatic = FindWindowEx(lngAOLChild, 0&, "_AOL_Static", vbNullString)
    
    If lngRICHCNTL <> 0 And lngAOLIcon <> 0 And lngAOLStatic <> 0 Then
        IsChatRoom = True
    End If
    
    Exit Function
PROC_ERR:
    MsgBox Err.Description, vbCritical
End Function

' ******************************************************************************
' Routine:        SetTopMostWindow
' Description:    Sets topmost window.
' Parameters:     hWnd (Long): Handle to set topmost.
'                 blnTopMost (Optional Boolean): True to set topmost, false otherwise.
'                                                If omited will set topmost.
' Returns:        Long value based on blnTopMost which is passed to SetWindowPos.
' Notes:          Review http://support.microsoft.com/support/kb/articles/Q150/2/33.ASP
'                 for important information.
' Example:
'     Call SetTopMostWindow(hWnd)
' ******************************************************************************
Public Function SetTopMostWindow _
       (hWnd As Long, _
       Optional blnTopMost As Boolean = True) As Long

    On Error GoTo PROC_ERR

    If IsWindow(hWnd) Then
        Select Case blnTopMost
            Case True
                SetTopMostWindow = SetWindowPos(hWnd, HWND_TOPMOST, 0&, 0&, 0&, 0&, FLAGS)
            Case False
                SetTopMostWindow = SetWindowPos(hWnd, HWND_NOTOPMOST, 0&, 0&, 0&, 0&, FLAGS)
                SetTopMostWindow = False
        End Select
    Else
        MsgBox INVALID_WINDOW, vbCritical
    End If

    Exit Function
PROC_ERR:
    MsgBox Err.Description, vbCritical
End Function

' ******************************************************************************
' Routine:        SysWait
' Description:    Suspends program operation.
' Parameters:     lngMilliseconds (Long): Number of milliseconds to wait.
' Notes:          If application needs to process other events during this period
'                 this will not allow it.
' Example:
'     Call SysWait(2000)
' ******************************************************************************
Public Sub SysWait(lngMilliseconds As Long)
    On Error GoTo PROC_ERR
  
    Call Sleep(lngMilliseconds)
  
    Exit Sub
PROC_ERR:
    MsgBox Err.Description, vbCritical
End Sub
